@@ -20,10 +20,10 @@
       '559292'='org.Sc.sgd.db',
       '7955'='org.Dr.eg.db')
 }
- 
+
 .taxIdToOrgDb <- function(taxid) {
     ## These are the packaged TaxIds
-    packageTaxIds <- .packageTaxIds() 
+    packageTaxIds <- .packageTaxIds()
     if (taxid %in% names(packageTaxIds)) {
         pkg <- packageTaxIds[names(packageTaxIds) %in% taxid]
         nmspc <- loadNamespace(pkg)
@@ -33,7 +33,7 @@
         ## for the hub objects
         loadNamespace("AnnotationHub")
         ah <- AnnotationHub::AnnotationHub()
-        ah <- subset(ah, ah$rdataclass=='OrgDb') 
+        ah <- subset(ah, ah$rdataclass=='OrgDb')
         mc <- mcols(ah)[,'taxonomyid', drop=FALSE]
         ## Then just get the object
         AHID <- rownames(mc[mc$taxonomyid==taxid,,drop=FALSE])
@@ -50,7 +50,7 @@
 
 ## Need another helper to get us from taxID to the OrgDbName...
 .taxIdToOrgDbName <- function(taxid) {
-    packageTaxIds <- .packageTaxIds() 
+    packageTaxIds <- .packageTaxIds()
     if (taxid %in% names(packageTaxIds)) {
         pkg <- packageTaxIds[names(packageTaxIds) %in% taxid]
         nmspc <- loadNamespace(pkg)
@@ -61,11 +61,11 @@
         ## for the hub objects
         loadNamespace("AnnotationHub")
         ah <- AnnotationHub::AnnotationHub()
-        ah <- subset(ah, ah$rdataclass=='OrgDb') 
+        ah <- subset(ah, ah$rdataclass=='OrgDb')
         mc <- mcols(ah)[,c('taxonomyid','title'), drop=FALSE]
         ## Then just get the object
         data <- mc[mc$taxonomyid==taxid,,drop=FALSE]
-        res <- sub("sqlite","db", data$title) 
+        res <- sub("sqlite","db", data$title)
     }
     res
 }
@@ -109,8 +109,8 @@
   pkgs <- unlist(lapply(names(fkeys), get))
   res <- logical(length(pkgs))
   for(i in seq_len(length(pkgs))){
-    res[i] <- fkeys[i] %in% columns(pkgs[[i]]) 
-  }  
+    res[i] <- fkeys[i] %in% columns(pkgs[[i]])
+  }
   if(!all(res))
     stop("some foreign keys are not present in their associated databases")
 }
@@ -155,9 +155,9 @@ makeOrganismPackage <- function(pkgname,
    ## Filter dependencies to make sure they are really package names
    biocPkgNames <- .biocAnnPackages()
    deps <- allDeps[allDeps %in% biocPkgNames]
-   depsStr <- paste(deps,collapse=", ")   
+   depsStr <- paste(deps,collapse=", ")
    ## We need to define some symbols in order to have the
-   ## template filled out correctly. 
+   ## template filled out correctly.
    symvals <- list(
     PKGTITLE=paste("Annotation package for the",pkgname,"object"),
     PKGDESCRIPTION=paste("Contains the",pkgname,"object",
@@ -165,7 +165,7 @@ makeOrganismPackage <- function(pkgname,
     PKGVERSION=version,
     AUTHOR=author,
     MAINTAINER=maintainer,
-    LIC=license,        
+    LIC=license,
     ORGANISM=organism,
     ORGANISMBIOCVIEW=gsub(" ","_",organism),
     PKGNAME=pkgname,
@@ -177,8 +177,8 @@ makeOrganismPackage <- function(pkgname,
 ## pkgs <- unique(names(.extractPkgsAndCols(gd)))
 ## for (pkg in pkgs)
 ##     .initPkg(pkg)
-   
-   ## ######################################################################### 
+
+   ## #########################################################################
    ## Extract the dbFile information from each object and store that
    ## into resources
 
@@ -188,15 +188,15 @@ makeOrganismPackage <- function(pkgname,
    ## TODO: change this so that it isn't getting a bunch of dbFiles
    ## and then throwing them aways (or so that it's optional with a
    ## parameter or whatever seems appropriate for this function)
-   
+
    resources <- .extractDbFiles(gd, deps)
    resources <- unlist(lapply(resources, function(x){return("")}))
-   ## ######################################################################### 
-   
+   ## #########################################################################
+
    ## Also check that the fkeys are really columns for the graphData
    fkeys <- .extractPkgsAndCols(gd)
    .testKeys(fkeys)
-   
+
    ## Should never have duplicates
    if (any(duplicated(names(symvals))))
        stop("'symvals' contains duplicated symbols")
@@ -219,7 +219,7 @@ makeOrganismPackage <- function(pkgname,
    graphInfo <- list(graphData=graphData, resources=resources)
    ## create data dir (because R CMD build removes empty dirs)
    ## And then save the data there.
-   dir.create(file.path(destDir,pkgname,"data"))   
+   dir.create(file.path(destDir,pkgname,"data"))
    save(graphInfo, file=file.path(destDir,pkgname,"data","graphInfo.rda"))
 
    ## Get and other things that need to be saved and stash them into
@@ -306,16 +306,16 @@ makeOrganismDbFromTxDb <- function(txdb, keytype=NA, orgdb=NA){
         stop("'orgdb' must be an OrgDb object or NA")
     if (!isSingleStringOrNA(keytype))
         stop("'keytype' must be a single string or NA")
-    
+
     ## Then assign that object value to the appropriate name:
     txdbName <- makePackageName(txdb)
     ## We temp assign to global scope
     ## (b/c you need it there if you 'generated' it)
     ## After we can remove it? (will be stored in the object)
-    assign(txdbName, txdb, .GlobalEnv)  
+    assign(txdbName, txdb, .GlobalEnv)
     ## Then get the tax ID:
     taxId <- taxonomyId(txdb)
-    
+
     ## Then get the name and valued for the OrgDb object
     if (!is(orgdb, "OrgDb") && is.na(orgdb)){
         orgdbName <- OrganismDbi:::.taxIdToOrgDbName(taxId)
@@ -334,23 +334,23 @@ makeOrganismDbFromTxDb <- function(txdb, keytype=NA, orgdb=NA){
     }else{
         geneKeyType <- keytype
     }
-       
+
     graphData <- list(join1 = setNames(object=c('GOID', 'GO'),
                                        nm=c('GO.db', orgdbName)),
                       join2 = setNames(object=c(geneKeyType, 'GENEID'),
                                        nm=c(orgdbName, txdbName)))
-    
+
     ## get the organism
     organism <- organism(txdb)
 
     #############################################################
     ## Process and then test the graph Data
     gd <- OrganismDbi:::.mungeGraphData(graphData)
-    OrganismDbi:::.testGraphData(gd)    
+    OrganismDbi:::.testGraphData(gd)
     allDeps <- unique(as.vector(gd[,1:2]))
     biocPkgNames <- OrganismDbi:::.biocAnnPackages()
     deps <- allDeps[allDeps %in% biocPkgNames]
-    resources <- OrganismDbi:::.gentlyExtractDbFiles(gd, deps)    
+    resources <- OrganismDbi:::.gentlyExtractDbFiles(gd, deps)
     ## Check that the fkeys are really columns for the graphData
     fkeys <- OrganismDbi:::.extractPkgsAndCols(gd)
     OrganismDbi:::.testKeys(fkeys)
@@ -386,12 +386,15 @@ makeOrganismDbFromBiomart <- function(biomart="ENSEMBL_MART_ENSEMBL",
                                       circ_seqs=NULL,
                                       filter="",
                                       id_prefix="ensembl_",
-                                      host="www.ensembl.org",
-                                      port=80,
+                                      host="https://www.ensembl.org",
+                                      port,
                                       miRBaseBuild=NA,
                                       keytype="ENSEMBL",
                                       orgdb = NA){
 
+    if (!missing(port))
+        warning("The 'port' argument is deprecated and will be ignored.")
+
     ## So call the function to make that TxDb
     txdb <- makeTxDbFromBiomart(biomart=biomart,
                                 dataset=dataset,
@@ -400,7 +403,6 @@ makeOrganismDbFromBiomart <- function(biomart="ENSEMBL_MART_ENSEMBL",
                                 filter=filter,
                                 id_prefix=id_prefix,
                                 host=host,
-                                port=port,
                                 miRBaseBuild=miRBaseBuild)
     makeOrganismDbFromTxDb(txdb, keytype=keytype, orgdb=orgdb)
 }
@@ -448,7 +450,7 @@ available.GTFsForTxDbs <- function() {
     ## get OrgDb species
     aho <- subset(ah, ah$rdataclass=='OrgDb')
     oTaxids <-unique(aho$taxonomyid)
-    
+
     ## get GTF species from ensembl
     ahg <- subset(ah, grepl('gtf.gz$',ah$sourceurl))
     ahg <- subset(ahg, ahg$dataprovider=='Ensembl')
@@ -456,7 +458,7 @@ available.GTFsForTxDbs <- function() {
     maxStr <- paste0("ftp://ftp.ensembl.org/pub/release-",max)
     ahg <- subset(ahg, grepl(maxStr,ahg$sourceurl))
     gTaxids <-unique(ahg$taxonomyid)
-    
+
     ## intersect of taxIds
     taxInt <- intersect(oTaxids, gTaxids)
     ## subset down to just the ahgs that can work...
@@ -480,8 +482,8 @@ makeHubGTFIntoTxDb <- function(ahg){
                                     taxonomyId=ahg$taxonomyid)
         require(OrganismDbi)
         ## requires using the 'ENSEMBL' keytype (for these TxDbs)
-        ## odb <- makeOrganismDbFromTxDb(txdb, keytype='ENSEMBL')        
-        odb <- makeOrganismDbFromTxDb(txdb)        
+        ## odb <- makeOrganismDbFromTxDb(txdb, keytype='ENSEMBL')
+        odb <- makeOrganismDbFromTxDb(txdb)
     }else{
         stop('No OrgDb information for ', ahg$species)
     }
